@@ -1,5 +1,5 @@
 /* Tarlz - Archiver with multimember lzip compression
-   Copyright (C) 2013-2025 Antonio Diaz Diaz.
+   Copyright (C) 2013-2026 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -212,7 +212,8 @@ public:
   };
 
 
-// send one ipacket with tar member metadata to courier and print filename
+/* Send one ipacket with tar member metadata to courier and print filename.
+   Call fill_headers from here instead of from cworker because of bsolid. */
 int add_member_lz( const char * const filename, const struct stat *,
                    const int flag, struct FTW * )
   {
